@@ -1,4 +1,8 @@
+#' spec_driver_constructor
+#' @family driver specifications
+#' @usage NULL
 #' @format NULL
+#' @keywords NULL
 #' @section Construction of the DBIDriver object:
 spec_driver_constructor <- list(
   constructor = function(ctx) {
@@ -17,20 +21,22 @@ spec_driver_constructor <- list(
     #' The constructor must be exported, and
     pkg_env <- getNamespace(pkg_name)
     eval(bquote(
-      expect_true(.(constructor_name) %in% getNamespaceExports(pkg_env))))
+      expect_true(.(constructor_name) %in% getNamespaceExports(pkg_env))
+    ))
 
     #' it must be a function
     eval(bquote(
-      expect_true(exists(.(constructor_name), mode = "function", pkg_env))))
+      expect_true(exists(.(constructor_name), mode = "function", pkg_env))
+    ))
     constructor <- get(constructor_name, mode = "function", pkg_env)
 
     #' that is callable without arguments.
-    expect_that(constructor, all_args_have_default_values())
+    expect_all_args_have_default_values(constructor)
     #' DBI recommends to define a constructor with an empty argument list.
     if (!isTRUE(ctx$tweaks$constructor_relax_args)) {
-      expect_that(constructor, arglist_is_empty())
+      expect_arglist_is_empty(constructor)
     }
   },
-
+  #
   NULL
 )
