@@ -1,6 +1,10 @@
 #' @format NULL
 spec_meta <- c(
+  spec_meta_bind_formals,
   spec_meta_bind,
+  spec_meta_arrow_bind,
+  spec_meta_stream_bind,
+  spec_meta_arrow_stream_bind,
   spec_meta_is_valid,
   spec_meta_has_completed,
   spec_meta_get_statement,
