@@ -9,12 +9,12 @@ spec_sql_unquote_identifier <- list(
     expect_equal(names(formals(dbUnquoteIdentifier)), c("conn", "x", "..."))
   },
 
-  #' @return
   unquote_identifier_return = function(con) {
+    #' @return
     #' `dbUnquoteIdentifier()` returns a list of objects
     simple_in <- dbQuoteIdentifier(con, "simple")
     simple_out <- dbUnquoteIdentifier(con, simple_in)
-    expect_is(simple_out, "list")
+    expect_type(simple_out, "list")
   },
   #
   unquote_identifier_vectorized = function(ctx, con) {
@@ -27,12 +27,16 @@ spec_sql_unquote_identifier <- list(
     letters_out <- dbUnquoteIdentifier(con, letters_in)
     expect_equal(length(letters_out), length(letters_in))
 
-    #' For an empty character vector this function returns a length-0 object.
+    #' For an empty vector, this function returns a length-0 object.
     empty <- character()
     empty_in <- dbQuoteIdentifier(con, empty)
     empty_out <- dbUnquoteIdentifier(con, empty_in)
     expect_equal(length(empty_out), 0)
 
+    empty_in <- character()
+    empty_out <- dbUnquoteIdentifier(con, empty_in)
+    expect_equal(length(empty_out), 0)
+
     #' The names of the input argument are preserved in the output.
     unnamed_in <- dbQuoteIdentifier(con, letters)
     unnamed_out <- dbUnquoteIdentifier(con, unnamed_in)
@@ -41,32 +45,42 @@ spec_sql_unquote_identifier <- list(
     named_out <- dbUnquoteIdentifier(con, named_in)
     expect_equal(names(named_out), letters[1:3])
 
-    #' When passing the first element of a returned object again to
-    #' `dbUnquoteIdentifier()` as `x`
-    #' argument, it is returned unchanged (but wrapped in a list).
+    #' If `x` is a value returned by `dbUnquoteIdentifier()`,
+    #' calling `dbUnquoteIdentifier(..., dbQuoteIdentifier(..., x))`
+    #' returns `list(x)`.
     expect_identical(dbUnquoteIdentifier(con, simple_out[[1]]), simple_out)
     expect_identical(dbUnquoteIdentifier(con, letters_out[[1]]), letters_out[1])
-    #' Passing objects of class [Id] should also return them unchanged (but wrapped in a list).
+    #' If `x` is an object of class [Id],
+    #' calling `dbUnquoteIdentifier(..., x)` returns `list(x)`.
     expect_identical(dbUnquoteIdentifier(con, Id(table = "simple")), list(Id(table = "simple")))
 
     #' (For backends it may be most convenient to return [Id] objects
     #' to achieve this behavior, but this is not required.)
   },
   #'
-  #' @section Failure modes:
-  unquote_identifier_error = function(ctx, con) {
+  unquote_identifier_plain = function(ctx, con) {
+    skip_if(ctx$tweaks$dbitest_version < "1.7.99.15")
+
+    #' Plain character vectors can also be passed to `dbUnquoteIdentifier()`.
+    expect_identical(dbUnquoteIdentifier(con, "a"), list(Id("a")))
+    expect_identical(dbUnquoteIdentifier(con, "a.b"), list(Id("a", "b")))
+    expect_identical(dbUnquoteIdentifier(con, "a.b.c"), list(Id("a", "b", "c")))
+    expect_identical(dbUnquoteIdentifier(con, "a.b.c.d"), list(Id("a", "b", "c", "d")))
+  },
+  #'
+  unquote_identifier_error = function(con) {
+    #' @section Failure modes:
     #'
-    #' An error is raised if plain character vectors are passed as the `x`
-    #' argument.
+    #' An error is raised if a character vectors with a missing value is passed
+    #' as the `x` argument.
     expect_error(dbUnquoteIdentifier(con, NA_character_))
     expect_error(dbUnquoteIdentifier(con, c("a", NA_character_)))
-    expect_error(dbUnquoteIdentifier(con, character()))
   },
 
-  #' @section Specification:
-  #' For any character vector of length one, quoting (with [dbQuoteIdentifier()])
-  #' then unquoting then quoting the first element is identical to just quoting.
-  unquote_identifier_roundtrip = function(ctx, con) {
+  unquote_identifier_roundtrip = function(con) {
+    #' @section Specification:
+    #' For any character vector of length one, quoting (with [dbQuoteIdentifier()])
+    #' then unquoting then quoting the first element is identical to just quoting.
     simple_in <- dbQuoteIdentifier(con, "simple")
     simple_out <- dbUnquoteIdentifier(con, simple_in)
     simple_roundtrip <- dbQuoteIdentifier(con, simple_out[[1]])
@@ -124,10 +138,10 @@ spec_sql_unquote_identifier <- list(
   },
 
   #'
-  #' Unquoting simple strings (consisting of only letters) wrapped with [SQL()]
-  #' and then quoting via [dbQuoteIdentifier()] gives the same result as just
-  #' quoting the string.
-  unquote_identifier_simple = function(ctx, con) {
+  unquote_identifier_simple = function(con) {
+    #' Unquoting simple strings (consisting of only letters) wrapped with [SQL()]
+    #' and then quoting via [dbQuoteIdentifier()] gives the same result as just
+    #' quoting the string.
     simple_in <- "simple"
     simple_quoted <- dbQuoteIdentifier(con, simple_in)
     simple_out <- dbUnquoteIdentifier(con, SQL(simple_in))
@@ -135,13 +149,13 @@ spec_sql_unquote_identifier <- list(
     expect_identical(simple_roundtrip, simple_quoted)
   },
 
-  #' Similarly, unquoting expressions of the form `SQL("schema.table")`
-  #' and then quoting gives the same result as quoting the identifier
-  #' constructed by `Id(schema = "schema", table = "table")`.
   unquote_identifier_table_schema = function(ctx, con) {
+    #' Similarly, unquoting expressions of the form `SQL("schema.table")`
+    #' and then quoting gives the same result as quoting the identifier
+    #' constructed by `Id("schema", "table")`.
     schema_in <- "schema"
     table_in <- "table"
-    simple_quoted <- dbQuoteIdentifier(con, Id(schema = schema_in, table = table_in))
+    simple_quoted <- dbQuoteIdentifier(con, Id(schema_in, table_in))
     simple_out <- dbUnquoteIdentifier(con, SQL(paste0(schema_in, ".", table_in)))
     simple_roundtrip <- dbQuoteIdentifier(con, simple_out[[1]])
     expect_identical(simple_roundtrip, simple_quoted)
